@@ -27,6 +27,10 @@ exclude_ignored_components = os.environ.get('EXCLUDE_IGNORED_COMPONENTS')
 if config.args.exclude_ignored_components:
     exclude_ignored_components = config.args.exclude_ignored_components
 
+modify_spdx_fields = os.environ.get('MODIFY_SPDX_FIELDS')
+if config.args.modify_spdx_fields:
+    modify_spdx_fields = config.args.modify_spdx_fields
+
 if config.args.blackduck_trust_certs:
     globals.verify = False
 
@@ -138,6 +142,37 @@ def run():
 
     print("Done")
 
+    # deal with filtering out certain fields from the final output based on command line input
+    if modify_spdx_fields is not None and modify_spdx_fields != '':
+        modification_instructions = modify_spdx_fields.split(',')
+        modification_instructions = [string.strip() for string in modification_instructions]
+    else:
+        modification_instructions = []
+
+    entrypoint = globals.spdx
+
+    def search_and_remove(json_object, levels, val):
+        level = levels[0]
+        if len(levels) == 1:
+            json_object.pop(level)
+            json_object[level] = val
+            return
+        if level == '[*]':
+            for item in json_object:
+                search_and_remove(item, levels[1:], val)
+        else:
+            if level in json_object:
+                search_and_remove(json_object[level], levels[1:], val)
+
+    for instruction in modification_instructions:
+        inst = instruction.split(';')
+        field_descriptor = inst[0]
+        modified_value = inst[1]
+        fields = field_descriptor.split('.')
+        print(f'Replacing {field_descriptor} with {modified_value}')
+        search_and_remove(entrypoint, fields, modified_value)
+
+    # write the result to the file system
     spdx.write_spdx_file(globals.spdx)
 
 
